# pykoi frontend

This is the frontend for the pykoi library. It includes interfaces and UI components for data collection, feedback, and visualization.

To see it in action, check out the various examples in the `example/` repo.

## Recommended IDE Setup

[VS Code](https://code.visualstudio.com/) + [Svelte](https://marketplace.visualstudio.com/items?itemName=svelte.svelte-vscode).

## Need an official Svelte framework?

Check out [SvelteKit](https://github.com/sveltejs/kit#readme), which is also powered by Vite. Deploy anywhere with its serverless-first approach and adapt to various platforms, with out of the box support for TypeScript, SCSS, and Less, and easily-added support for mdsvex, GraphQL, PostCSS, Tailwind CSS, and more.

## Technical considerations

All UI components are built using Svelte.

## Development

To develop new frontend components, you'll have to make sure everything is installed, then launch with npm:

```
npm install
npm run dev
```
